@@ -28,14 +28,14 @@ extern pmdaInterface	dispatch;
 extern int		infd;
 extern int		outfd;
 
-__pmProfile		*profile = NULL;
+__pmProfile		*profile;
 int			profile_changed;
-int			timer = 0;
-int			get_desc = 0;
+int			timer;
+int			get_desc;
 
 static pmID		*pmidlist;
 static int		numpmid;
-static __pmContext	ctx;
+static __pmContext	*ctxp;
 
 static char	**argv;
 static int	argc;
@@ -59,12 +59,27 @@ reset_profile(void)
 	__pmNoMem("reset_profile", sizeof(__pmProfile), PM_FATAL_ERR);
 	exit(1);
     }
-    ctx.c_instprof = profile;
+    ctxp->c_instprof = profile;
     memset(profile, 0, sizeof(__pmProfile));
     profile->state = PM_PROFILE_INCLUDE;        /* default global state */
     profile_changed = 1;
 }
 
+void
+setup_context(void)
+{
+    int sts;
+
+    if ((sts = pmNewContext(PM_CONTEXT_LOCAL | PM_CTXFLAG_SHALLOW, NULL)) < 0) {
+	fprintf(stderr, "setup_context: creation failed: %s\n", pmErrStr(sts));
+	exit(1);
+    }
+    ctxp = __pmHandleToPtr(sts);
+    memset(ctxp, 0, sizeof(__pmContext));
+    ctxp->c_type = PM_CONTEXT_HOST;
+    reset_profile();
+}
+
 char *
 strcons(char *s1, char *s2)
 {
@@ -185,29 +200,6 @@ printindom(FILE *f, __pmInResult *irp)
     }
 }
 
-/*
- * Fake out a context for use with the profile routines
- */
-
-int pmWhichContext(void)
-{
-    static int		first = 1;
-
-    if (first) {
-	memset(&ctx, 0, sizeof(__pmContext));
-	ctx.c_type = PM_CONTEXT_HOST;
-	reset_profile();
-	first = 0;
-    }
-    return 0;
-}
-
-__pmContext *
-__pmHandleToPtr(int dummy)
-{
-    return(&ctx);
-}
-
 void
 dohelp(int command, int full)
 {
@@ -269,6 +261,7 @@ dohelp(int command, int full)
 	case OPEN:
 	    puts("open dso dsoname init_routine [ domain# ]");
 	    puts("open pipe execname [ arg ... ]");
+	    puts("open socket sockname");
 	    break;
 	case PMNS_CHILDREN:
 	    puts("children metric-name");
@@ -357,10 +350,12 @@ dohelp(int command, int full)
 		break;
 	    case OPEN:
 		puts(
-"Open a PMDA as either a DSO or a daemon (connected with a pipe).  The\n"
-"'dsoname' and 'execname' fields are the path to the PMDA shared object file\n"
-"or executable.  The arguments to this command are similar to a line in the\n"
-"pmcd.conf file.\n");
+"Open a PMDA as either a DSO, via UNIX domain socket (named pipe), or as a\n"
+"daemon (connected with a pipe).  The 'dsoname' and 'execname' fields are\n"
+"the path to the PMDA shared object file or executable.  The 'sockname'\n"
+"field is the path of a named pipe where a PMDA is listening for connections.\n"
+"The arguments to this command are similar to a line in the pmcd.conf file.\n");
+
 		break;
 	    case PMNS_CHILDREN:
 	        puts(
