@@ -561,7 +561,8 @@ void
 __pmNoMem(const char *where, size_t size, int fatal)
 {
     __pmNotifyErr(fatal ? LOG_ERR : LOG_WARNING,
-		 "%s: malloc(%d) failed: %s", where, size, strerror(errno));
+			"%s: malloc(%d) failed: %s",
+			where, (int)size, strerror(errno));
     if (fatal)
 	exit(1);
 }
@@ -696,7 +697,7 @@ __pmEventTrace(const char *event)
     struct timeval tv;
     double now;
 
-    gettimeofday(&tv, NULL);
+    __pmtimevalNow(&tv);
     now = (double)tv.tv_sec + (double)tv.tv_usec / 1000000.0;
     if (!first)
         sum += now - last;
