@@ -61,8 +61,10 @@ refresh_net_dev_ioctl(char *name, net_interface_t *netip)
     }
     if (!(ioctl(fd, SIOCGIFMTU, &ifr) < 0))
 	netip->ioc.mtu = ifr.ifr_mtu;
-    if (!(ioctl(fd, SIOCGIFFLAGS, &ifr) < 0))
-	netip->ioc.linkup = (ifr.ifr_flags & IFF_UP);
+    if (!(ioctl(fd, SIOCGIFFLAGS, &ifr) < 0)) {
+	netip->ioc.linkup = !!(ifr.ifr_flags & IFF_UP);
+	netip->ioc.running = !!(ifr.ifr_flags & IFF_RUNNING);
+    }
 }
 
 void
@@ -89,10 +91,9 @@ refresh_proc_net_dev(pmInDom indom)
 {
     char		buf[1024];
     FILE		*fp;
-    int			j;
     unsigned long long	llval;
-    char		*p;
-    int			sts;
+    char		*p, *v;
+    int			j, sts;
     net_interface_t	*netip;
 
     static uint64_t	gen;	/* refresh generation number */
@@ -120,7 +121,7 @@ Inter-|   Receive                                                |  Transmit
     pmdaCacheOp(indom, PMDA_CACHE_INACTIVE);
 
     while (fgets(buf, sizeof(buf), fp) != NULL) {
-	if ((p = strchr(buf, ':')) == NULL)
+	if ((p = v = strchr(buf, ':')) == NULL)
 	    continue;
 	*p = '\0';
 	for (p=buf; *p && isspace(*p); p++) {;}
@@ -165,7 +166,7 @@ Inter-|   Receive                                                |  Transmit
 	/* Issue ioctls for remaining data, not exported through proc */
 	refresh_net_dev_ioctl(p, netip);
 
-	for (p=buf+6, j=0; j < PROC_DEV_COUNTERS_PER_LINE; j++) {
+	for (p=v, j=0; j < PROC_DEV_COUNTERS_PER_LINE; j++) {
 	    for (; !isdigit(*p); p++) {;}
 	    sscanf(p, "%llu", &llval);
 	    if (llval >= netip->last_counters[j]) {
