@@ -14,23 +14,11 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: pmhostname.c,v 1.3 2003/02/20 05:28:13 kenmcd Exp $"
+#include "pmapi.h"
+#include "impl.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/param.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <netdb.h>
-
-/*ARGSUSED*/
 int
 main(int argc, char **argv)
 {
@@ -38,6 +26,8 @@ main(int argc, char **argv)
     char        	host[MAXHOSTNAMELEN];
     struct hostent      *hep = NULL;
 
+    __pmSetProgname(argv[0]);
+
     if (argc == 1) {
 	(void)gethostname(host, MAXHOSTNAMELEN);
 	name = host;
@@ -56,6 +46,4 @@ main(int argc, char **argv)
         printf("%s\n", hep->h_name);
 
     exit(0);
-    /*NOTREACHED*/
-
 }
