@@ -98,6 +98,9 @@ extern pmUnits	countUnits;
 /* default context type */
 extern int	dfltConn;
 
+/* flag processes spawned */
+extern int	need_wait;
+
 #endif /* PRAG_H */
 
 
